==> em_tasks-0.1.65-py2.py3-none-any.whl: em_tasks/tools/amz_unuploadable_products_formatter.py <==
# -*- coding: utf-8 -*-

import json

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.product_util import ProductUtil
from em_tasks.utils.product_converters import AmzProductConverter
from em_tasks.utils.pipelines.amz_products_filter import AmzProductsFilterPipeline
from em_tasks.store.models import *



class AmzUnuploadableProductsFormatter():
  def __init__(self, store_code, marketplace, product_service, offer_service,  output_path):
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return
    self.products_path = None
    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))


    self.product_service = product_service
    self.offer_service = offer_service
    self.marketplace = marketplace.lower()
    self.pc = AmzProductConverter(self.marketplace)
    self.indice_name = 'amz_products_api_{}'.format(marketplace.lower())
    self.condition = 'new'
    self.output_path = os.path.abspath(os.path.expanduser(output_path))
    output_dir = os.path.dirname(self.output_path)
    if not os.path.isdir(output_dir):
      os.makedirs(output_dir)
    self.output_fh = open(self.output_path, 'w+', encoding='utf-8', errors='ignore')

    self.sales_rank_min = 1000000
    self.weight_max = 2.5
    self.dimension_max = 20
    if self.marketplace == 'us':
      self.dimension_max = 30
    elif self.marketplace == 'uk':
      self.sales_rank_min = 1500000
      self.weight_max = 2
      self.dimension_max = 12
    else:
      self.sales_rank_min = 1500000
      self.dimension_max = 20

    self.unuploadable_path = os.path.abspath(os.path.join(os.path.expanduser('~'), '.em_tasks', 'amz_{}'.format(self.marketplace), 'unuploadable_products.txt'))
    unuploadable_dir = os.path.dirname(self.unuploadable_path)
    if not os.path.isdir(unuploadable_dir):
      os.makedirs(unuploadable_dir)

    self.unuploadable_products = dict()

    self.products_filter_pipeline = AmzProductsFilterPipeline(self.marketplace, self.weight_max, self.dimension_max, self.sales_rank_min)

  def run(self):
    count = 0
    try:
      for prod_id, prod in self.product_service.load_products(self.indice_name):
        count += 1
        result = self.products_filter_pipeline.check_product(prod)
        passed = result.get('passed', True)
        reason = result.get('reason', '')
        if not passed:
          self.unuploadable_products[prod_id] = reason
          logger.debug('[ProductFiltered] ASIN: %s, Reason: Unuploadable - %s', prod_id, reason)
          if len(self.unuploadable_products) > 1000:
            self.save_unuploadable_products()
            self.unuploadable_products = {}

    finally:
      self.output_fh.close()
      print(f"total checked product count: {count}")

      self.save_unuploadable_products()


  def save_unuploadable_products(self):
    if not self.unuploadable_products:
      return

    records = []
    with open(self.output_path, 'w+', encoding='utf-8', errors='ignore') as fh:
      for pid, reason in self.unuploadable_products.items():
        records.append('{},{}'.format(pid, reason))

      fh.write("\n".join(records))
      fh.write("\n")

==> em_tasks-0.1.68-py2.py3-none-any.whl: em_tasks/tools/amz_unuploadable_products_formatter.py <==
# -*- coding: utf-8 -*-

import json

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.product_util import ProductUtil
from em_tasks.utils.product_converters import AmzProductConverter
from em_tasks.utils.pipelines.amz_products_filter import AmzProductsFilterPipeline
from em_tasks.store.models import *


class AmzUnuploadableProductsFormatter:
  def __init__(
    self, store_code, marketplace, product_service, offer_service, output_path
  ):
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return
    self.products_path = None
    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(
      credential["endpoint"], credential["api_key"], credential.get("api_version", "v1")
    )

    self.product_service = product_service
    self.offer_service = offer_service
    self.marketplace = marketplace.lower()
    self.pc = AmzProductConverter(self.marketplace)
    self.indice_name = "amz_products_api_{}".format(marketplace.lower())
    self.condition = "new"
    self.output_path = os.path.abspath(os.path.expanduser(output_path))
    output_dir = os.path.dirname(self.output_path)
    if not os.path.isdir(output_dir):
      os.makedirs(output_dir)
    self.output_fh = open(self.output_path, "w+", encoding="utf-8", errors="ignore")

    self.sales_rank_min = 1000000
    self.weight_max = 2.5
    self.dimension_max = 20
    if self.marketplace == "us":
      self.dimension_max = 30
    elif self.marketplace == "uk":
      self.sales_rank_min = 1500000
      self.weight_max = 2
      self.dimension_max = 12
    else:
      self.sales_rank_min = 1500000
      self.dimension_max = 20

    self.unuploadable_path = os.path.abspath(
      os.path.join(
        os.path.expanduser("~"),
        ".em_tasks",
        "amz_{}".format(self.marketplace),
        "unuploadable_products.txt",
      )
    )
    unuploadable_dir = os.path.dirname(self.unuploadable_path)
    if not os.path.isdir(unuploadable_dir):
      os.makedirs(unuploadable_dir)

    self.unuploadable_products = dict()

    self.products_filter_pipeline = AmzProductsFilterPipeline(
      self.marketplace, self.weight_max, self.dimension_max, self.sales_rank_min
    )

  def run(self):
    count = 0
    try:
      for prod_id, prod in self.product_service.load_products(self.indice_name):
        count += 1
        result = self.products_filter_pipeline.check_product(prod)
        passed = result.get("passed", True)
        reason = result.get("reason", "")
        if not passed:
          self.unuploadable_products[prod_id] = reason
          logger.debug(
            "[ProductFiltered] ASIN: %s, Reason: Unuploadable - %s", prod_id, reason
          )

    finally:
      self.output_fh.close()
      print(f"total checked product count: {count}")

      self.save_unuploadable_products()

  def save_unuploadable_products(self):
    if not self.unuploadable_products:
      return

    records = []
    with open(self.output_path, "w+", encoding="utf-8", errors="ignore") as fh:
      for pid, reason in self.unuploadable_products.items():
        records.append("{},{}".format(pid, reason))

      fh.write("\n".join(records))
      fh.write("\n")
